@@ -18,8 +18,8 @@ from kabaret.subprocess_manager.runners import Explorer
 from kabaret.flow_entities.store import EntityStore
 
 from .users import Users, UserEnvironment, UserBookmarks, UserProfile
-from .film import Sequences
 from .lib import Assets
+from .shot import SequenceCollection
 from .runners import (
     Krita,
     Blender,
@@ -41,7 +41,7 @@ from .site import (
     MinioFileUploader, MinioFileDownloader,
     RequestRevisions, MultiRequestRevisions,
 )
-from .file import TrackedFile, Revision, FileManager, DefaultFileMap
+from .file import TrackedFile, Revision, DefaultFileMap
 from .kitsu import KitsuAPIWrapper, KitsuBindings
 from .dependency import DependencyTemplates
 
@@ -545,7 +545,6 @@ class Admin(flow.Object):
 
     login_page = flow.Child(LoginPage).ui(hidden=True)
 
-    file_manager = flow.Child(FileManager)
     store = flow.Child(EntityStore)
 
 
@@ -555,7 +554,7 @@ class Project(flow.Object):
 
     user = flow.Child(UserProfile)
     asset_lib = flow.Child(Assets).ui(expanded=True)
-    sequences = flow.Child(Sequences).ui(expanded=True)
+    sequences = flow.Child(SequenceCollection).ui(expanded=True)
     admin = flow.Child(Admin)
     synchronization = flow.Child(Synchronization).ui(expanded=True)
 
@@ -734,12 +733,6 @@ class Project(flow.Object):
     def log_out(self):
         self.kitsu_api().log_out()
     
-    def kitsu_id(self):
-        return self.admin.kitsu.project_id.get()
-
-    def kitsu_name(self):
-        return self.admin.kitsu.project_name.get()
-    
     def kitsu_config(self):
         return self.admin.kitsu
     
@@ -846,8 +839,17 @@ class Project(flow.Object):
     def get_entity_store(self):
         return self.admin.store
     
-    def get_file_manager(self):
-        return self.admin.file_manager
+    def get_entity_manager(self):
+        raise NotImplementedError((
+            'This method must return the entity manager holding '
+            'the collections of entities of this project.'
+        ))
+
+    def get_task_manager(self):
+        raise NotImplementedError((
+            'This method must return the task manager holding '
+            'the default tasks and task templates of this project.'
+        ))
     
     def get_sync_manager(self):
         return self.synchronization.synchronize_files
