@@ -148,7 +148,7 @@ class FileSystemItem:
     def oid(self):
         return (
               self.entity_oid()
-            + "/departments/"
+            + "/tasks/"
             + self._department
             + "/files/"
             + self.flow_name()
@@ -716,7 +716,7 @@ class DependencyFile(flow.Object):
         return name
 
     def _get_root_oid(self):
-        return self._dependency.dependency_oid.get() + '/departments/' + self.department.get() + '/files'
+        return self._dependency.dependency_oid.get() + '/tasks/' + self.department.get() + '/files'
 
     def get_oid(self):
         return self._get_root_oid() + '/' + self.name()
