@@ -5,15 +5,19 @@ from fnmatch import fnmatch
 
 from kabaret import flow
 from kabaret.flow_contextual_dict import ContextualView, get_contextual_dict
+from kabaret.flow_entities.entities import Entity
+
+from ..utils.kabaret.flow_entities.entities import EntityView
 
 from .departments import Department
-from .maputils import ItemMap, CreateItemAction, ClearMapAction
+from .maputils import ItemMap, CreateItemAction, ClearMapAction, SimpleCreateAction
 from .lib import AssetDependency, DropAssetAction  # , KitsuSettingsView
 from .kitsu import KitsuSequence, KitsuShot, UpdateItemsKitsuSettings
 from .site import RequestRevisions, MultiRequestRevisions, MultiRequestedRevisions, SiteJobsPoolNames, ActiveSiteChoiceValue, ActiveSitesMultichoiceValue, RequestedRevisions
 from .dependency import get_dependencies
 from .file import GenericRunAction
 from .users import ToggleBookmarkAction
+from .shot import SequenceCollection
 
 
 class Casting(flow.Map):
@@ -158,7 +162,7 @@ class ShotElementSelection(flow.Object):
     
     def _get_revision_oids(self, root_oid, file_name, file_data, include_dependencies=False, latest_dependencies=False):
         # Check if given file exists
-        file_oid = "%s/departments/%s/files/%s" % (
+        file_oid = "%s/tasks/%s/files/%s" % (
             root_oid,
             file_data['department'],
             file_name.replace('.', '_')
@@ -330,10 +334,10 @@ class ComparePreviews(GenericRunAction):
     task_2 = flow.Param('Compositing', PlayblastChoiceValue).watched()
 
     FILE_BY_TASK = {
-        'Layout': '/departments/layout/files/layout_movie_mov',
-        'Blocking': '/departments/animation/files/blocking_movie_mov',
-        'Animation': '/departments/animation/files/animation_movie_mov',
-        'Compositing': '/departments/compositing/files/compositing_movie_mov'
+        'Layout': '/tasks/layout/files/layout_movie_mov',
+        'Blocking': '/tasks/animation/files/blocking_movie_mov',
+        'Animation': '/tasks/animation/files/animation_movie_mov',
+        'Compositing': '/tasks/compositing/files/compositing_movie_mov'
     }
 
     def runner_name_and_tags(self):
@@ -418,7 +422,7 @@ class Shot(KitsuShot):
     # casting = flow.Child(Casting)
 
     description = flow.Param("")
-    departments = flow.Child(ShotDepartments).ui(expanded=True)
+    tasks = flow.Child(ShotDepartments).ui(expanded=True)
     
     request = flow.Child(RequestShot)
     multi_request = flow.Child(MultiRequestShot)
@@ -644,7 +648,7 @@ class PlayblastFile(PlayblastItem):
         return file_object.get_revision_names(published_only=True)
 
     def _compute_file_oid(self):
-        return '%s/shots/%s/departments/%s/files/%s' % (
+        return '%s/shots/%s/tasks/%s/files/%s' % (
             self._sequence.oid(),
             self._shot_pb.name(),
             self.department.get(),
@@ -942,7 +946,7 @@ class RenderSequencePlayblasts(ProcessSequenceFiles):
     
     def submit_blender_playblast_job(self, shot_name, dept_name, file_name, revision_name, use_simplify, reduce_textures, target_texture_width, priority=10, pool_name='default'):
         file_name = file_name.replace('.', '_')
-        oid = f'{self._sequence.oid()}/shots/{shot_name}/departments/{dept_name}/files/{file_name}'
+        oid = f'{self._sequence.oid()}/shots/{shot_name}/tasks/{dept_name}/files/{file_name}'
         file = self.root().get_object(oid)
         
         file.submit_blender_playblast_job.revision_name.set(revision_name)
@@ -955,7 +959,7 @@ class RenderSequencePlayblasts(ProcessSequenceFiles):
     
     def submit_afterfx_playblast_job(self, shot_name, dept_name, file_name, revision_name, priority=10, pool_name='default'):
         file_name = file_name.replace('.', '_')
-        oid = f'{self._sequence.oid()}/shots/{shot_name}/departments/{dept_name}/files/{file_name}'
+        oid = f'{self._sequence.oid()}/shots/{shot_name}/tasks/{dept_name}/files/{file_name}'
         file = self.root().get_object(oid)
         
         file.submit_ae_playblast.revision.set(revision_name)
@@ -979,7 +983,7 @@ class RenderSequencePlayblasts(ProcessSequenceFiles):
                 for file_name, file_data in task_files:
                     file_mapped_name = file_name.replace('.', '_')
                     dept_name = file_data['department']
-                    file_oid = f'{shot.oid()}/departments/{dept_name}/files/{file_mapped_name}'
+                    file_oid = f'{shot.oid()}/tasks/{dept_name}/files/{file_mapped_name}'
                     
                     if not self.root().session().cmds.Flow.exists(file_oid):
                         # Skip if file does not exist in the flow
@@ -1072,7 +1076,7 @@ class UploadSequencePlayblastsToKitsu(ProcessSequenceFiles):
                 for file_name, file_data in task_files:
                     file_mapped_name = file_name.replace('.', '_')
                     dept_name = file_data['department']
-                    file_oid = f'{shot.oid()}/departments/{dept_name}/files/{file_mapped_name}'
+                    file_oid = f'{shot.oid()}/tasks/{dept_name}/files/{file_mapped_name}'
                     
                     if not self.root().session().cmds.Flow.exists(file_oid):
                         # Skip if file does not exist in the flow
@@ -1165,7 +1169,7 @@ class ClearSequencesAction(ClearMapAction):
         super(ClearSequencesAction, self).run(button)
 
 
-class Sequences(ItemMap):
+class Sequences_XX(ItemMap):
 
     ICON = ("icons.flow", "sequence")
 
@@ -1187,3 +1191,46 @@ class Sequences(ItemMap):
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
             return dict(file_category="PROD")
+
+
+class Film(Entity):
+    """
+    Defines a film containing a list of sequences.
+
+    Instances provide the `film` key in their contextual
+    dictionary (`settings` context).
+    """
+
+    ICON = ('icons.flow', 'film')
+
+    sequences = flow.Child(SequenceCollection).ui(
+        expanded=True,
+        show_filter=True
+    )
+
+    @classmethod
+    def get_source_display(cls, oid):
+        split = oid.split('/')
+        return split[3]
+    
+    def get_default_contextual_edits(self, context_name):
+        if context_name == 'settings':
+            return dict(film=self.name())
+
+
+class FilmCollection(EntityView):
+    """
+    Defines a collection of films.
+    """
+
+    ICON = ('icons.flow', 'film')
+
+    add_film = flow.Child(SimpleCreateAction)
+
+    @classmethod
+    def mapped_type(cls):
+        return flow.injection.injectable(Film)
+    
+    def collection_name(self):
+        mgr = self.root().project().get_entity_manager()
+        return mgr.get_film_collection().collection_name()
